==> tuia-news-center-api-0.0.28-zwb15-20180515.133838-2-sources.jar: cn/com/duiba/tuia/news/center/dto/UpdateActivityDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;

public class UpdateActivityDto  implements Serializable{

    /**
     * 活动
     */
    private Long   id;
    /**
     * 活动名称
     */
    private String activityName;

    /**
     * 活动url
     */
    private String activityUrl;

    /**
     * 活动图片地址
     */
    private String activityImage;

    /**
     * 活动图片(大)地址
     */
    private String activityBigImage;

    /**
     * 活动来源
     */
    private String activitySource;

    /**
     * 类目
     */
    private String tip;
    /**
     * 广告Id
     */
    private String activityId;

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getTip() {
        return tip;
    }

    public void setTip(String tip) {
        this.tip = tip;
    }

    public String getActivityBigImage() {
        return activityBigImage;
    }

    public void setActivityBigImage(String activityBigImage) {
        this.activityBigImage = activityBigImage;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public String getActivityImage() {
        return activityImage;
    }

    public void setActivityImage(String activityImage) {
        this.activityImage = activityImage;
    }

    public String getActivitySource() {
        return activitySource;
    }

    public void setActivitySource(String activitySource) {
        this.activitySource = activitySource;
    }
}

==> tuia-news-center-api-1.8.4.0.zwb-20190103.070424-2-sources.jar: cn/com/duiba/tuia/news/center/dto/UpdateActivityDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;

public class UpdateActivityDto  implements Serializable{

    /**
     * 活动
     */
    private Long   id;
    /**
     * 活动名称
     */
    private String activityName;

    /**
     * 活动url
     */
    private String activityUrl;

    /**
     * 活动图片地址
     */
    private String activityImage;

    /**
     * 活动图片(大)地址
     */
    private String activityBigImage;

    /**
     * 活动来源
     */
    private String activitySource;

    /**
     * 类目
     */
    private String tip;
    /**
     * 广告Id
     */
    private String activityId;

    /**
     * 活动小小图
     */
    private String activitySmallImage;

    /**
     * 图文模式 0：上文下图 1：左文右图
     */
    private Integer schemaMode;

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getTip() {
        return tip;
    }

    public void setTip(String tip) {
        this.tip = tip;
    }

    public String getActivityBigImage() {
        return activityBigImage;
    }

    public void setActivityBigImage(String activityBigImage) {
        this.activityBigImage = activityBigImage;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public String getActivityImage() {
        return activityImage;
    }

    public void setActivityImage(String activityImage) {
        this.activityImage = activityImage;
    }

    public String getActivitySource() {
        return activitySource;
    }

    public void setActivitySource(String activitySource) {
        this.activitySource = activitySource;
    }

    public String getActivitySmallImage() {
        return activitySmallImage;
    }

    public void setActivitySmallImage(String activitySmallImage) {
        this.activitySmallImage = activitySmallImage;
    }

    public Integer getSchemaMode() {
        return schemaMode;
    }

    public void setSchemaMode(Integer schemaMode) {
        this.schemaMode = schemaMode;
    }
}
